@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # input  definitons
 #
-# $Id: inputtags.pm,v 1.229 2007/08/14 19:32:42 albertel Exp $
+# $Id: inputtags.pm,v 1.231 2007/09/26 19:30:30 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1131,7 +1131,12 @@ sub gradestatus {
 	}
 	if ( $showbutton ) { 
 	    if ($target ne 'tex') {
-		$button = '<input onsubmit="javascript:setSubmittedPart(\''.$id.'\')" type="submit" name="submit_'.$id.'" value="'.&mt('Submit Answer').'" />';
+		$button = 
+		    '<input 
+                          onmouseup="javascript:setSubmittedPart(\''.$id.'\')"
+                           onsubmit="javascript:setSubmittedPart(\''.$id.'\')"
+                        type="submit" name="submit_'.$id.'"
+                         value="'.&mt('Submit Answer').'" />';
 	    }
 	}
 
@@ -1235,12 +1240,15 @@ sub previous_tries {
 				        'inherit_jsmath' => 1, });
     my $end_page =
 	&Apache::loncommon::end_page({'js_ready' => 1,});
-    
+    my $prefix = $env{'form.request.prefix'};
+    $prefix =~ tr{.}{_};
+    my $function_name = "LONCAPA_previous_tries_".$prefix.
+	$Apache::lonxml::curdepth;
     my $result ="<script type=\"text/javascript\">
 // <![CDATA[
-    function LONCAPA_previous_tries_$Apache::lonxml::curdepth() {newWindow=open('','new_W','width=500,height=500,scrollbars=1,resizable=yes');newWindow.$windowopen;newWindow.document.writeln('$start_page $output $end_page');newWindow.document.close();newWindow.focus()}
+    function $function_name() {newWindow=open('','new_W','width=500,height=500,scrollbars=1,resizable=yes');newWindow.$windowopen;newWindow.document.writeln('$start_page $output $end_page');newWindow.document.close();newWindow.focus()}
 // ]]>
-</script><a href=\"javascript:LONCAPA_previous_tries_$Apache::lonxml::curdepth();void(0);\">".&mt("Previous Tries")."</a><br />";
+</script><a href=\"javascript:$function_name();void(0);\">".&mt("Previous Tries")."</a><br />";
     #use Data::Dumper;
     #&Apache::lonnet::logthis(&Dumper(\%Apache::inputtags::submission_display));
     return $result;
