@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # The LON-CAPA Homework handler
 #
-# $Id: lonhomework.pm,v 1.268.2.1 2007/09/06 14:41:00 albertel Exp $
+# $Id: lonhomework.pm,v 1.268.2.2 2007/09/21 17:25:58 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -196,7 +196,8 @@ sub check_ip_acc {
 	return 1;
     }
     my $allowed=0;
-    my $ip=$ENV{'REMOTE_ADDR'};
+    my $ip=$env{'request.host'} || $ENV{'REMOTE_ADDR'};
+
     my $name;
     foreach my $pattern (split(',',$acc)) {
 	$pattern =~ s/^\s*//;
