@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler for displaying the course catalog interface
 #
-# $Id: coursecatalog.pm,v 1.19 2007/01/14 01:59:37 raeburn Exp $
+# $Id: coursecatalog.pm,v 1.20 2007/03/08 01:58:44 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -68,7 +68,7 @@ sub handler {
         }
     }
     my $formname = 'coursecatalog';
-    my $domdesc = $Apache::lonnet::domaindescription{$codedom};
+    my $domdesc = &Apache::lonnet::domain($codedom,'description');
 
     &Apache::lonhtmlcommon::clear_breadcrumbs();
     if ($env{'form.coursenum'} ne '' && &user_is_known()) {
