@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler to set domain-wide configuration settings
 #
-# $Id: domainprefs.pm,v 1.24 2007/07/28 21:23:53 raeburn Exp $
+# $Id: domainprefs.pm,v 1.25 2007/08/26 15:31:03 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -895,9 +895,7 @@ sub print_directorysrch {
     my ($dom,$settings) = @_;
     my $srchon = ' ';
     my $srchoff = ' checked="checked" ';
-    my $exacton = '';
-    my $containson = ' checked="checked" ';
-    my $specifyon = '';
+    my ($exacton,$containson,$beginson);
     my $localon = ' ';
     my $localoff = ' checked="checked" ';
     if (ref($settings) eq 'HASH') {
@@ -909,13 +907,25 @@ sub print_directorysrch {
             $localon = $localoff;
             $localoff = ' ';
         }
-        if ($settings->{'searchtypes'} eq 'exact') {
-            $exacton = $containson;
-            $containson = ' ';
-        }
-        if ($settings->{'searchtypes'} eq 'specify') {
-            $specifyon = $containson;
-            $containson = ' ';
+        if (ref($settings->{'searchtypes'}) eq 'ARRAY') {
+            foreach my $type (@{$settings->{'searchtypes'}}) {
+                if ($type eq 'exact') {
+                    $exacton = ' checked="checked" ';
+                } elsif ($type eq 'contains') {
+                    $containson = ' checked="checked" ';
+                } elsif ($type eq 'begins') {
+                    $beginson = ' checked="checked" ';
+                }
+            }
+        } else {
+            if ($settings->{'searchtypes'} eq 'exact') {
+                $exacton = ' checked="checked" ';
+            } elsif ($settings->{'searchtypes'} eq 'contains') {
+                $containson = ' checked="checked" ';
+            } elsif ($settings->{'searchtypes'} eq 'specify') {
+                $exacton = ' checked="checked" ';
+                $containson = ' checked="checked" ';
+            }
         }
     }
     my ($searchtitles,$titleorder) = &sorted_searchtitles();
@@ -930,68 +940,16 @@ sub print_directorysrch {
                   '<label><input type="radio" name="dirsrch_available"'.
                   $srchoff.' value="0" />'.&mt('No').'</label></span></td>'.
                   '</tr><tr>'.
-                  '<td colspan="2">'.&mt('Search latitude').'</td>'.
-                  '<td class="LC_right_item"><span class="LC_nobreak"><label>'.
-                  '<input type="radio" name="searchtypes"'.
-                  $exacton.' value="exact" />'.&mt('Exact match only').'</label>&nbsp;'.
-                  '<label><input type="radio" name="searchtypes"'.
-                  $containson.' value="contains" />'.&mt('Contains is a match').'</label>'.
-                  '&nbsp;<label><input type="radio" name="searchtypes"'.
-                  $specifyon.' value="specify" />'.&mt('Specifiable type').
-                  '</label></span></td></tr>'.
-                  '<tr class="LC_odd_row">'.
-                  '<td colspan="2">'.&mt('Other domains can search').'</td>'.
+                  '<td colspan="2">'.&mt('Other domains can search?').'</td>'.
                   '<td class="LC_right_item"><span class="LC_nobreak"><label>'.
                   '<input type="radio" name="dirsrch_localonly"'.
                   $localoff.' value="0" />'.&mt('Yes').'</label>&nbsp;'.
                   '<label><input type="radio" name="dirsrch_localonly"'.
                   $localon.' value="1" />'.&mt('No').'</label></span></td>'.
-                  '</tr><tr>'.
-                  '<td>'.&mt('Users allowed to search').' ('.$dom.')'.
-                  '</td><td class="LC_left_item" colspan="2"><table>';
-    for (my $i=0; $i<@{$types}; $i++) {
-        if (defined($usertypes->{$types->[$i]})) {
-            my $rem = $i%($numinrow);
-            if ($rem == 0) {
-                if ($i > 0) {
-                    $datatable .= '</tr>';
-                }
-                $datatable .= '<tr>';
-            }
-            my $check = ' ';
-            if (ref($settings->{'cansearch'}) eq 'ARRAY') {
-                if (grep(/^\Q$types->[$i]\E$/,@{$settings->{'cansearch'}})) {
-                    $check = ' checked="checked" ';
-                }
-            }
-            $datatable .= '<td class="LC_left_item">'.
-                          '<span class="LC_nobreak"><label>'.
-                          '<input type="checkbox" name="cansearch" '.
-                          'value="'.$types->[$i].'"'.$check.'/>'.
-                          $usertypes->{$types->[$i]}.'</label></span></td>';
-        }
-    }
-
-    my $rem = @{$types}%($numinrow);
-    my $colsleft = $numinrow - $rem;
-    if ($colsleft > 1) {
-        $datatable .= '<td colspan="'.$colsleft.'" class="LC_left_item">';
-    } else {
-        $datatable .= '<td class="LC_left_item">';
-    }
-    my $defcheck = ' ';
-    if (ref($settings->{'cansearch'}) eq 'ARRAY') {
-         if (grep(/^default$/,@{$settings->{'cansearch'}})) {
-              $defcheck = ' checked="checked" ';
-         }
-    }
-    $datatable .= '<span class="LC_nobreak"><label>'.
-                  '<input type="checkbox" name="cansearch" '.
-                  'value="default"'.$defcheck.'/>'.
-                  $othertitle.'</label></span></td>'.
-                  '</tr></table></td></tr>';
-
-    $datatable .= '<tr class="LC_odd_row">'.
+                  '</tr>';
+    $datatable .= &users_cansearch_row($settings,$types,$usertypes,$dom,
+                                       $numinrow,$othertitle);
+    $datatable .= '<tr>'.
                   '<td>'.&mt('Supported search methods').
                   '</td><td class="LC_left_item" colspan="2"><table><tr>';
     foreach my $title (@{$titleorder}) {
@@ -1009,10 +967,71 @@ sub print_directorysrch {
                           $searchtitles->{$title}.'</label></span></td>';
         }
     }
-    $datatable .= '</tr></table></td></tr>';
+    $datatable .= '</tr></table></td></tr><tr class="LC_odd_row">'. 
+                  '<td>'.&mt('Search latitude').'</td>'.
+                  '<td class="LC_left_item"  colspan="2">'.
+                  '<span class="LC_nobreak"><label>'.
+                  '<input type="checkbox" name="searchtypes" '.
+                  $exacton.' value="exact" />'.&mt('Exact match').
+                  '</label>&nbsp;'.
+                  '<label><input type="checkbox" name="searchtypes" '.
+                  $beginson.' value="begins" />'.&mt('Begins with').
+                  '</label>&nbsp;'.
+                  '<label><input type="checkbox" name="searchtypes" '.
+                  $containson.' value="contains" />'.&mt('Contains').
+                  '</label></span></td></tr>';
     return $datatable;
 }
 
+sub users_cansearch_row {
+    my ($settings,$types,$usertypes,$dom,$numinrow,$othertitle) = @_;
+    my $output =  '<tr class="LC_odd_row">'.
+                  '<td>'.&mt('Users allowed to search').' ('.$dom.')'.
+                  '</td><td class="LC_left_item" colspan="2"><table>';
+    for (my $i=0; $i<@{$types}; $i++) {
+        if (defined($usertypes->{$types->[$i]})) {
+            my $rem = $i%($numinrow);
+            if ($rem == 0) {
+                if ($i > 0) {
+                    $output .= '</tr>';
+                }
+                $output .= '<tr>';
+            }
+            my $check = ' ';
+            if (ref($settings->{'cansearch'}) eq 'ARRAY') {
+                if (grep(/^\Q$types->[$i]\E$/,@{$settings->{'cansearch'}})) {
+                    $check = ' checked="checked" ';
+                }
+            }
+            $output .= '<td class="LC_left_item">'.
+                       '<span class="LC_nobreak"><label>'.
+                       '<input type="checkbox" name="cansearch" '.
+                       'value="'.$types->[$i].'"'.$check.'/>'.
+                       $usertypes->{$types->[$i]}.'</label></span></td>';
+        }
+    }
+
+    my $rem = @{$types}%($numinrow);
+    my $colsleft = $numinrow - $rem;
+    if ($colsleft > 1) {
+        $output .= '<td colspan="'.$colsleft.'" class="LC_left_item">';
+    } else {
+        $output .= '<td class="LC_left_item">';
+    }
+    my $defcheck = ' ';
+    if (ref($settings->{'cansearch'}) eq 'ARRAY') {
+         if (grep(/^default$/,@{$settings->{'cansearch'}})) {
+              $defcheck = ' checked="checked" ';
+         }
+    }
+    $output .= '<span class="LC_nobreak"><label>'.
+               '<input type="checkbox" name="cansearch" '.
+               'value="default"'.$defcheck.'/>'.
+               $othertitle.'</label></span></td>'.
+               '</tr></table></td></tr>';
+    return $output;
+}
+
 sub sorted_inst_types {
     my ($dom) = @_;
     my ($usertypes,$order) = &Apache::lonnet::retrieve_inst_usertypes($dom);
@@ -1042,6 +1061,16 @@ sub sorted_searchtitles {
     return (\%searchtitles,\@titleorder);
 }
 
+sub sorted_searchtypes {
+    my %srchtypes_desc = (
+                           exact    => 'is exact match',
+                           contains => 'contains ..',
+                           begins   => 'begins with ..',
+                         );
+    my @srchtypeorder = ('exact','begins','contains');
+    return (\%srchtypes_desc,\@srchtypeorder);
+}
+
 sub usertype_update_row {
     my ($settings,$usertypes,$fieldtitles,$fields,$types,$rownums) = @_;
     my $datatable;
@@ -1948,6 +1977,7 @@ sub modify_directorysrch {
     my @offon = ('off','on');
     my @otherdoms = ('Yes','No');
 
+    my @searchtypes = &Apache::loncommon::get_env_multiple('form.searchtypes');  
     my @cansearch = &Apache::loncommon::get_env_multiple('form.cansearch');
     my @searchby = &Apache::loncommon::get_env_multiple('form.searchby');
 
@@ -1980,13 +2010,39 @@ sub modify_directorysrch {
     } else {
         push(@{$changes{'searchby'}},@searchby);
     }
-    
+
+    if (ref($currdirsrch{'searchtypes'}) eq 'ARRAY') {
+        foreach my $type (@{$currdirsrch{'searchtypes'}}) {
+            if (!grep(/^\Q$type\E$/,@searchtypes)) {
+                push(@{$changes{'searchtypes'}},$type);
+            }
+        }
+        foreach my $type (@searchtypes) {
+            if (!grep(/^\Q$type\E$/,@{$currdirsrch{'searchtypes'}})) {
+                push(@{$changes{'searchtypes'}},$type);
+            }
+        }
+    } else {
+        if (exists($currdirsrch{'searchtypes'})) {
+            foreach my $type (@searchtypes) {  
+                if ($type ne $currdirsrch{'searchtypes'}) { 
+                    push(@{$changes{'searchtypes'}},$type);
+                }
+            }
+            if (!grep(/^\Q$currdirsrch{'searchtypes'}\E/,@searchtypes)) {
+                push(@{$changes{'searchtypes'}},$currdirsrch{'searchtypes'});
+            }   
+        } else {
+            push(@{$changes{'searchtypes'}},@searchtypes); 
+        }
+    }
+
     my %dirsrch_hash =  (
             directorysrch => { available => $env{'form.dirsrch_available'},
                                cansearch => \@cansearch,
                                localonly => $env{'form.dirsrch_localonly'},
                                searchby => \@searchby,
-                               searchtypes => $env{'form.searchtypes'},
+                               searchtypes => \@searchtypes,
                              }
             );
     my $putresult = &Apache::lonnet::put_dom('configuration',\%dirsrch_hash,
@@ -2010,15 +2066,6 @@ sub modify_directorysrch {
                 $changes{'localonly'} = 1;
             }
         }
-        if (exists($currdirsrch{'searchtypes'})) {
-             if ($currdirsrch{'searchtypes'} ne $env{'form.searchtypes'}) {
-                 $changes{'searchtypes'} = 1;
-             }
-        } else {
-            if ($env{'form.searchtypes'}) {
-                $changes{'searchtypes'} = 1;
-            }
-        }
         if (keys(%changes) > 0) {
             $resulttext = &mt('Changes made:').'<ul>';
             if ($changes{'available'}) {
@@ -2056,13 +2103,18 @@ sub modify_directorysrch {
                 $chgtext =~ s/\; $//;
                 $resulttext .= '<li>'.&mt("$title{'searchby'} set to: [_1]",$chgtext).'</li>';
             }
-            if ($changes{'searchtypes'}) {
-                my %srchtypes_desc = ( 
-                                       exact => 'Exact match only',
-                                       contains => 'Contains is a match',
-                                       specify => 'Match type specifiable',
-                                     );
-                $resulttext .= '<li>'.&mt("$title{'searchtypes'} set to: \"$srchtypes_desc{$env{'form.searchtypes'}}\"").'</li>';
+            if (ref($changes{'searchtypes'}) eq 'ARRAY') {
+                my ($srchtypes_desc,$srchtypeorder) = &sorted_searchtypes(); 
+                my $chgtext;
+                foreach my $type (@{$srchtypeorder}) {
+                    if (grep(/^\Q$type\E$/,@searchtypes)) {
+                        if (defined($srchtypes_desc->{$type})) {
+                            $chgtext .= $srchtypes_desc->{$type}.'; ';
+                        }
+                    }
+                }
+                $chgtext =~ s/\; $//;
+                $resulttext .= '<li>'.&mt("$title{'searchtypes'} set to: \"[_1]\"",$chgtext).'</li>';
             }
             $resulttext .= '</ul>';
         } else {
@@ -2076,4 +2128,3 @@ sub modify_directorysrch {
 }
 
 1;
-
