@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # a pile of common html routines
 #
-# $Id: lonhtmlcommon.pm,v 1.160 2007/07/11 20:32:15 albertel Exp $
+# $Id: lonhtmlcommon.pm,v 1.161 2007/09/05 05:00:24 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1329,7 +1329,7 @@ returns: nothing
 # row2
 # row3   ... etc.
 # &submit_row(0
-# &end_pickbox()
+# &end_pick_box()
 #
 # where row1, row 2 etc. are chosen from &role_select_row,&course_select_row,
 # &status_select_row and &email_default_row
@@ -1567,7 +1567,6 @@ sub status_select_row {
 sub email_default_row {
     my ($authtypes,$title,$descrip,$css_class) = @_;
     my $output = &row_title($title,$css_class);
-    my @rowcols = ('#eeeeee','#dddddd');
     $output .= $descrip.
 	&Apache::loncommon::start_data_table().
 	&Apache::loncommon::start_data_table_header_row().
