@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Routines to control the menu
 #
-# $Id: lonmenu.pm,v 1.222 2007/07/17 18:31:37 albertel Exp $
+# $Id: lonmenu.pm,v 1.222.2.1 2007/08/30 22:37:27 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -885,9 +885,9 @@ sub switch {
        my $lonhttpdPort=$Apache::lonnet::perlvar{'lonhttpdPort'};
        if (!defined($lonhttpdPort)) { $lonhttpdPort='8080'; }
        my $pic=
-	   '<img alt="'.$text.'" src="http://'.$ENV{'HTTP_HOST'}.
-	   ':'.$lonhttpdPort.'/res/adm/pages/'.$img.'" align="'.
-	   ($nobreak==3?'right':'left').'" />';
+	   '<img alt="'.$text.'" src="'.
+	   &Apache::loncommon::lonhttpdurl('/res/adm/pages/'.$img).
+	   '" align="'.($nobreak==3?'right':'left').'" />';
        if ($env{'browser.interface'} eq 'faketextual') {
 # Accessibility
 	   if ($nobreak==3) {
