@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Preferences
 #
-# $Id: lonpreferences.pm,v 1.104 2007/05/13 22:04:06 raeburn Exp $
+# $Id: lonpreferences.pm,v 1.109 2007/07/17 21:11:49 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -561,6 +561,48 @@ sub verify_and_change_icons {
     $r->print(&mt('Set menu mode to [_1].',$newicons));
 }
 
+################################################################
+#                     Clicker Subroutines                      #
+################################################################
+
+sub clickerchanger {
+    my $r = shift;
+    my $user       = $env{'user.name'};
+    my $domain     = $env{'user.domain'};
+    my %userenv = &Apache::lonnet::get
+        ('environment',['clickers']);
+    my $clickers=$userenv{'clickers'};
+    $clickers=~s/\,/\n/gs;
+    my $text=&mt('Enter response device ("clicker") numbers');
+    my $change=&mt('Register');
+    my $helplink=&Apache::loncommon::help_open_topic('Clicker_Registration', 'Locating your clicker ID');
+    $r->print(<<ENDSCREEN);
+<form name="prefs" action="/adm/preferences" method="post">
+<input type="hidden" name="action" value="verify_and_change_clicker" />
+<label>$text $helplink<br />
+<textarea name="clickers" rows="5" cols="20">$clickers</textarea>
+</label>
+<input type="submit" value="$change" />
+</form>
+ENDSCREEN
+}
+
+sub verify_and_change_clicker {
+    my $r = shift;
+    my $user       = $env{'user.name'};
+    my $domain     = $env{'user.domain'};
+    my $newclickers  = $env{'form.clickers'};
+    $newclickers=~s/[^\w\:\-]+/\,/gs;
+    $newclickers=~tr/a-z/A-Z/;
+    $newclickers=~s/[\:\-]+/\-/g;
+    $newclickers=~s/\,+/\,/g;
+    $newclickers=~s/^\,//;
+    $newclickers=~s/\,$//;
+    &Apache::lonnet::put('environment',{'clickers' => $newclickers});
+    &Apache::lonnet::appenv('environment.clickers' => $newclickers);
+    $r->print(&mt('Registering clickers: [_1]',$newclickers));
+}
+
 ################################################################
 #         Message Forward                                      #
 ################################################################
@@ -870,6 +912,7 @@ sub verify_and_change_msgforward {
     if ($message) {
         $message .= '<br /><hr />';
     }
+    &Apache::loncommon::flush_email_cache($user,$domain);
     &msgforwardchanger($r,$message);
 }
 
@@ -1762,6 +1805,23 @@ sub handler {
                       printmenu => 'yes',
                       }));
 
+    push (@Options,({ action   => 'changeclicker',
+                      linktext => 'Register Response Devices ("Clickers")',
+                      href     => '/adm/preferences',
+                      subroutine => \&clickerchanger,
+                      breadcrumb =>
+                          { href => '/adm/preferences?action=changeicons',
+                            text => 'Register Clicker'},
+                      },
+                    { action   => 'verify_and_change_clicker',
+                      subroutine => \&verify_and_change_clicker,
+                      breadcrumb =>
+                          { href => '/adm/preferences?action=changeclicker',
+                            text => 'Register Clicker'},
+                      printmenu => 'yes',
+                      }));
+
+
     if (&Apache::lonnet::allowed('whn',$env{'request.course.id'})
 	|| &Apache::lonnet::allowed('whn',$env{'request.course.id'}.'/'
 				    .$env{'request.course.sec'})) {
