@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Page Handler
 #
-# $Id: lonpage.pm,v 1.84 2007/07/10 20:51:41 albertel Exp $
+# $Id: lonpage.pm,v 1.84.2.1 2007/09/26 00:34:31 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -388,7 +388,7 @@ sub handler {
 								    'bgcolor'        => '#ffffff',}));
 # ------------------------------------------------------------------ Start form
 			  if ($nforms) {
-			      $r->print('<form name="lonhomework" method="post" action="'.
+			      $r->print('<form name="lonhomework" method="post"  enctype="multipart/form-data" action="'.
 					&Apache::lonenc::check_encrypt($requrl)
 					.'">');
 			  }
